@@ -207,31 +207,6 @@ pub fn write_stops(
     Ok(())
 }
 
-fn get_gtfs_trip_shortname_and_headsign_from_ntfs_vj(
-    vj: &objects::VehicleJourney,
-    sps: &CollectionWithId<objects::StopPoint>,
-) -> (Option<String>, Option<String>) {
-    fn get_last_stop_name(
-        vj: &objects::VehicleJourney,
-        sps: &CollectionWithId<objects::StopPoint>,
-    ) -> Option<String> {
-        vj.stop_times
-            .last()
-            .map(|st| &sps[st.stop_point_idx].name)
-            .cloned()
-    }
-
-    match vj.physical_mode_id.as_str() {
-        "LocalTrain" | "LongDistanceTrain" | "Metro" | "RapidTransit" | "Train" => {
-            (vj.headsign.clone(), get_last_stop_name(vj, sps))
-        }
-        _ => (
-            None,
-            vj.headsign.clone().or_else(|| get_last_stop_name(vj, sps)),
-        ),
-    }
-}
-
 fn get_gtfs_direction_id_from_ntfs_route(route: &objects::Route) -> DirectionType {
     match route.direction_type.as_deref() {
         Some("forward") | Some("clockwise") | Some("inbound") => DirectionType::Forward,
@@ -240,8 +215,6 @@ fn get_gtfs_direction_id_from_ntfs_route(route: &objects::Route) -> DirectionTyp
 }
 
 fn make_gtfs_trip_from_ntfs_vj(vj: &objects::VehicleJourney, model: &Model) -> Trip {
-    let (short_name, headsign) =
-        get_gtfs_trip_shortname_and_headsign_from_ntfs_vj(vj, &model.stop_points);
     let mut wheelchair_and_bike = (Availability::default(), Availability::default());
     if let Some(tp_id) = &vj.trip_property_id {
         if let Some(tp) = &model.trip_properties.get(&tp_id) {
@@ -260,8 +233,8 @@ fn make_gtfs_trip_from_ntfs_vj(vj: &objects::VehicleJourney, model: &Model) -> T
         route_id: route_id.to_string(),
         service_id: vj.service_id.clone(),
         id: vj.id.clone(),
-        headsign,
-        short_name,
+        headsign: vj.headsign.clone(),
+        short_name: vj.short_name.clone(),
         direction: get_gtfs_direction_id_from_ntfs_route(&route),
         block_id: vj.block_id.clone(),
         shape_id: vj.geometry_id.clone(),
@@ -529,10 +502,7 @@ mod tests {
         calendars::write_calendar_dates,
         gtfs::{Route, RouteType, StopLocationType, Transfer, TransferType},
         model::Collections,
-        objects::{
-            Calendar, CommentLinksT, Coord, KeysValues, StopPoint, StopTime,
-            Transfer as NtfsTransfer,
-        },
+        objects::{Calendar, CommentLinksT, Coord, StopPoint, StopTime, Transfer as NtfsTransfer},
     };
     use geo::{line_string, point};
     use pretty_assertions::assert_eq;
@@ -768,7 +738,7 @@ mod tests {
             ]
             .into_iter()
             .collect(),
-            object_properties: BTreeSet::default(),
+            object_properties: PropertiesMap::default(),
             comment_links,
             visible: true,
             coord: objects::Coord {
@@ -914,7 +884,7 @@ mod tests {
         let vj = objects::VehicleJourney {
             id: "OIF:87604986-1_11595-1".to_string(),
             codes: BTreeSet::default(),
-            object_properties: BTreeSet::default(),
+            object_properties: PropertiesMap::default(),
             comment_links: BTreeSet::default(),
             route_id: "OIF:078078001:1".to_string(),
             physical_mode_id: "Bus".to_string(),
@@ -959,7 +929,7 @@ mod tests {
         let vj_coach = objects::VehicleJourney {
             id: "OIF:87604986-1_11595-1:Coach".to_string(),
             codes: BTreeSet::default(),
-            object_properties: BTreeSet::default(),
+            object_properties: PropertiesMap::default(),
             comment_links: BTreeSet::default(),
             route_id: "OIF:078078001:1".to_string(),
             physical_mode_id: "Coach".to_string(),
@@ -1007,7 +977,7 @@ mod tests {
             service_id: vj.service_id.clone(),
             id: "OIF:87604986-1_11595-1".to_string(),
             headsign: Some("2005".to_string()),
-            short_name: None,
+            short_name: Some("42".to_string()),
             direction: DirectionType::Forward,
             block_id: Some("PLOI".to_string()),
             shape_id: vj.geometry_id.clone(),
@@ -1031,7 +1001,7 @@ mod tests {
             id: "sa:01".to_string(),
             name: "sa:01".to_string(),
             codes: sa_codes,
-            object_properties: KeysValues::default(),
+            object_properties: PropertiesMap::default(),
             comment_links: CommentLinksT::default(),
             visible: true,
             coord: Coord {
@@ -1231,7 +1201,7 @@ mod tests {
         let vehicle_journeys = CollectionWithId::from(VehicleJourney {
             id: "vj:01".to_string(),
             codes: BTreeSet::new(),
-            object_properties: KeysValues::default(),
+            object_properties: PropertiesMap::default(),
             comment_links: CommentLinksT::default(),
             route_id: "r:01".to_string(),
             physical_mode_id: "pm:01".to_string(),
@@ -1305,7 +1275,7 @@ mod tests {
             name: "3".to_string(),
             code: None,
             codes: BTreeSet::default(),
-            object_properties: BTreeSet::default(),
+            object_properties: PropertiesMap::default(),
             comment_links: BTreeSet::default(),
             forward_name: None,
             forward_direction: None,
@@ -1353,7 +1323,7 @@ mod tests {
             name: "DEF".to_string(),
             code: Some("DEF".to_string()),
             codes: BTreeSet::default(),
-            object_properties: BTreeSet::default(),
+            object_properties: PropertiesMap::default(),
             comment_links: BTreeSet::default(),
             forward_name: Some("Hôtels - Hôtels".to_string()),
             forward_direction: Some("OIF:SA:4:126".to_string()),
